package io.swagger.api;

import java.util.Date;
import io.swagger.model.ErrorObj;
import io.swagger.model.HrrrForecastPointHourObj;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;
import java.util.Map;
import javax.ws.rs.*;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.MediaType;
import org.apache.cxf.jaxrs.ext.multipart.*;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;

/**
 * HRRR Forecast - A Weather Source API
 *
 * <p>Quarterhourly forecast data from the HRRR model for latitude/longitude points, ZIP/Postal Codes, and Designated Market Areas. Quarterhourly forecast goes out 18 hours and is available in 15 minute increments. The Weather Source HRRR Forecast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis.    **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.   
 *
 */
@Path("/")
public interface PointsApi  {

    /**
     * The complete quarterhourly HRRR forecast for a Latitude/Longitude point.
     *
     * Returns the complete set of HRRR forecast data for a Latitude/Longitude point.  *Alternatively using a query that specificies just the quarterhours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/points/{latitude},{longitude}/quarterhours")
    @Produces({ "application/json" })
    @Operation(summary = "The complete quarterhourly HRRR forecast for a Latitude/Longitude point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Quarterhourly HRRR forecast response for a Latitude/Longitude point.", content = @Content(mediaType = "application/json", schema = @Schema(implementation = HrrrForecastPointHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(mediaType = "application/json", schema = @Schema(implementation = ErrorObj.class))) })
    public HrrrForecastPointHourObj pointsLatitudelongitudeQuarterhoursGet(@PathParam("latitude") Float latitude, @PathParam("longitude") Float longitude, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * A quarterhour of HRRR forecast data for a Latitude/Longitude point.
     *
     * Returns a single quarterhour of HRRR forecast data for a Latitude/Longitude point. The provided timestamp must exist within the current valid 18 hour forecast range.  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/points/{latitude},{longitude}/quarterhours/{timestamp}")
    @Produces({ "application/json" })
    @Operation(summary = "A quarterhour of HRRR forecast data for a Latitude/Longitude point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Quarterhourly HRRR forecast response for a Latitude/Longitude point.", content = @Content(mediaType = "application/json", schema = @Schema(implementation = HrrrForecastPointHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(mediaType = "application/json", schema = @Schema(implementation = ErrorObj.class))) })
    public HrrrForecastPointHourObj pointsLatitudelongitudeQuarterhoursTimestampGet(@PathParam("latitude") Float latitude, @PathParam("longitude") Float longitude, @PathParam("timestamp") Date timestamp, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);

    /**
     * A contiguous range of quarterhourly HRRR forecast data for a Latitude/Longitude point.
     *
     * Returns a contiguous range of quarterhourly HRRR forecast data for a Latitude/Longitude point. The provided timestamps must exist within the current valid 18 hour forecast range.  **IMPORTANT:** To authenticate to the Weather Source HRRR Forecast API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/points/{latitude},{longitude}/quarterhours/{timestampStart},{timestampEnd}")
    @Produces({ "application/json" })
    @Operation(summary = "A contiguous range of quarterhourly HRRR forecast data for a Latitude/Longitude point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "Quarterhourly HRRR forecast response for a Latitude/Longitude point.", content = @Content(mediaType = "application/json", schema = @Schema(implementation = HrrrForecastPointHourObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(mediaType = "application/json", schema = @Schema(implementation = ErrorObj.class))) })
    public HrrrForecastPointHourObj pointsLatitudelongitudeQuarterhoursTimestampStarttimestampEndGet(@PathParam("latitude") Float latitude, @PathParam("longitude") Float longitude, @PathParam("timestampStart") Date timestampStart, @PathParam("timestampEnd") Date timestampEnd, @QueryParam("fields")List<String> fields, @QueryParam("unitScale")@DefaultValue("IMPERIAL") String unitScale);
}
